@@ -31,8 +31,8 @@ add_line <- function(ax,
   } else {
     apex_type <- ax$x$mixed_type
   }
-  if (!isTRUE(apex_type %in% c("line", "bar", "scatter")))
-    stop("add_line: apex() must be a column or scatter chart.", call. = FALSE)
+  if (!isTRUE(apex_type %in% c("line", "bar", "scatter", "candlestick")))
+    stop("add_line: apex() must be a column, scatter or candlestick chart.", call. = FALSE)
   ax$x$ax_opts$chart$type <- "line"
   if (is.null(data))
     data <- ax$x$data
@@ -40,7 +40,7 @@ add_line <- function(ax,
   mapdata <- lapply(mapping, rlang::eval_tidy, data = data)
   ax$x$ax_opts$series <- c(
     ax$x$ax_opts$series,
-    make_series(mapdata, mapping, type, serie_name)
+    make_series(mapdata, mapping, type, serie_name, force_datetime_names = c("x", "y"))
   )
   if (identical(apex_type, "scatter")) {
     if (is.null(ax$x$ax_opts$markers$size)) {
@@ -56,6 +56,13 @@ add_line <- function(ax,
       ax$x$ax_opts$stroke$width <- c(ax$x$ax_opts$stroke$width, 4)
     }
   }
+  if (identical(apex_type, "candlestick")) {
+    if (is.null(ax$x$ax_opts$stroke$width)) {
+      ax$x$ax_opts$stroke$width <- c(1, 4)
+    } else {
+      ax$x$ax_opts$stroke$width <- c(ax$x$ax_opts$stroke$width, 4)
+    }
+  }
   if (identical(type, "line")) {
     ax$x$ax_opts$stroke$curve <- "straight"
   } else if (identical(type, "spline")) {
