@@ -1,7 +1,8 @@
 ## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
-  comment = "#>"
+  comment = "#>",
+  screenshot.force = FALSE
 )
 
 ## ----packages, message=FALSE, warning=FALSE-----------------------------------
