@@ -31,4 +31,17 @@ test_that("all apex utilities works", {
 })
 
 
+test_that("ax_nodata works", {
+  empty <- data.frame(
+    var1 = character(0),
+    var2 = numeric(0)
+  )
+  ax <- apex(empty, aes(var1, var2), "column") %>% 
+    ax_nodata(
+      text = "Sorry no data to visualize",
+      fontSize = "30px"
+    )
+  expect_is(ax, "apexcharter")
+  expect_is(ax$x$ax_opts$noData, "list")
+})
 
